```
██████╗  ██████╗ ██╗    ██╗███████╗██████╗
██╔══██╗██╔═══██╗██║    ██║██╔════╝██╔══██╗
██████╔╝██║   ██║██║ █╗ ██║█████╗  ██████╔╝
██╔═══╝ ██║   ██║██║███╗██║██╔══╝  ██╔══██╗
██║     ╚██████╔╝╚███╔███╔╝███████╗██║  ██║
╚═╝      ╚═════╝  ╚══╝╚══╝ ╚══════╝╚═╝  ╚═╝
```
# interface CacheItemInterface (Details)
> namespace: **VDM\Psr\Cache**
```uml
@startuml
interface CacheItemInterface  #Lavender {
  + getKey() : string
  + get() : mixed
  + isHit() : bool
  + set(mixed $value) : static
  + expiresAt(?\DateTimeInterface $expiration) : static
  + expiresAfter(int|\DateInterval|null $time) : static
}

note right of CacheItemInterface::getKey
  Returns the key for the current cache item.
The key is loaded by the Implementing Library, but should be available to
the higher level callers when needed.
The key string for this cache item.

  return: string
end note

note right of CacheItemInterface::get
  Retrieves the value of the item from the cache associated with this object's key.
The value returned must be identical to the value originally stored by set().
If isHit() returns false, this method MUST return null. Note that null
is a legitimate cached value, so the isHit() method SHOULD be used to
differentiate between "null value was found" and "no value was found."
The value corresponding to this cache item's key, or null if not found.

  return: mixed
end note

note right of CacheItemInterface::isHit
  Confirms if the cache item lookup resulted in a cache hit.
Note: This method MUST NOT have a race condition between calling isHit()
and calling get().
True if the request resulted in a cache hit. False otherwise.

  return: bool
end note

note right of CacheItemInterface::set
  Sets the value represented by this cache item.
The $value argument may be any item that can be serialized by PHP,
although the method of serialization is left up to the Implementing
Library.
The serializable value to be stored.
The invoked object.

  return: static
end note

note right of CacheItemInterface::expiresAt
  Sets the expiration time for this cache item.
The point in time after which the item MUST be considered expired.
If null is passed explicitly, a default value MAY be used. If none is set,
the value should be stored permanently or for as long as the
implementation allows.
The called object.

  return: static
end note

note right of CacheItemInterface::expiresAfter
  Sets the expiration time for this cache item.
The period of time from the present after which the item MUST be considered
expired. An integer parameter is understood to be the time in seconds until
expiration. If null is passed explicitly, a default value MAY be used.
If none is set, the value should be stored permanently or for as long as the
implementation allows.
The called object.

  return: static
end note
 
@enduml
```

---
```
     ██╗ ██████╗██████╗
     ██║██╔════╝██╔══██╗
     ██║██║     ██████╔╝
██   ██║██║     ██╔══██╗
╚█████╔╝╚██████╗██████╔╝
 ╚════╝  ╚═════╝╚═════╝
```
> Build with [Joomla Component Builder](https://git.vdm.dev/joomla/Component-Builder)

